from .fields import VersionField
from .version import Version

default_app_config = "versionfield.apps.VersionFieldConfig"


